* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [SAP BTP, Cloud Foundry Integration for SAP Discovery](https://help.sap.com/docs/leanix/ea/configuring-sap-btp-cloud-foundry-integration)
  * Configuring SAP BTP, Cloud Foundry Integration Usin…
